/* Copyright 2011 Cloudseal O
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.cloudseal.spring.client.userdetails;

import org.jetbrains.annotations.Nullable;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.security.saml.SAMLCredential;
import org.springframework.security.saml.userdetails.SAMLUserDetailsService;

public class SAMLUserDetailsServiceAdapter implements SAMLUserDetailsService {
    
    private UserDetailsService userDetailsService;

    @Override
    public UserDetails loadUserBySAML(SAMLCredential credential) throws UsernameNotFoundException {
        CloudsealUserAttributes attributes = new CloudsealUserAttributes(credential);
        if (userDetailsService == null) {
            return new CloudsealUserDetails(attributes);
        } else if (CloudSealUserDetailsService.class.isInstance(userDetailsService)) {
            return ((CloudSealUserDetailsService) userDetailsService).loadUserByUsername(attributes);
        }
        return userDetailsService.loadUserByUsername(attributes.getUserName());
    }

    public void setUserDetailsService(@Nullable UserDetailsService userDetailsService) {
        this.userDetailsService = userDetailsService;
    }

}
